/*
Murasaki - multiple genome global alignment program
Copyright (C) 2006-2007 Keio University
(Kris Popendorf) <comp@bio.keio.ac.jp> (2006)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

//////////////////
// timing tools
// timing.h
// Kris Popendorf
/////////////////

#include "timing.h"
#include <math.h>
#include <stdio.h>

ostream& operator <<(ostream &os,const Timer &obj){
  return os << obj.asDouble();
}
  
double Timer::asDouble() const{
  return TIME_DOUBLE(tv);
}

void Timer::reset(){
  gettimeofday(&tv,NULL);
}

Timer::Timer(){
  reset();
}

Timer operator- (const Timer&a,const Timer &b){
  return Timer((TIME_DOUBLE(a.tv)-TIME_DOUBLE(b.tv)));
}

Timer::Timer(double t){
  tv.tv_sec=(int)t;
  tv.tv_usec=(int)(t*1000.0);
}

string elapsed(Timer start,Timer stop){
  double dur=(stop-start).asDouble();
  char buf[300];
  string str;
  int days=(int)(dur/60/60/24);
  dur-=days*60*60*24;
  int hours=(int)(dur/60/60);
  dur-=hours*60*60;
  int mins=(int)(dur/60);
  dur-=mins*60;
  if(days){
    sprintf(buf,days==1 ? "%d day ":"%d days ",days);
    str.append(string(buf));
  }
  if(hours){
    sprintf(buf,hours==1 ? "%d hour ":"%d hours ",hours);
    str.append(string(buf));
  }
  if(mins){
    sprintf(buf,mins==1 ? "%d minute ":"%d minutes ",mins);
    str.append(string(buf));
  }
  if(dur || (!hours && !days && !mins)){
    sprintf(buf,dur==1 ? "%.3f second ":"%.3f seconds",dur);
    str.append(string(buf));
  }
  return str;
}
